From 83baaa469f81d6620b941da81a7c374f4dc784c9 Mon Sep 17 00:00:00 2001
From: Jakob Linskeseder <jakob@linskeseder.com>
Date: Sun, 2 Jan 2022 02:06:47 +0100
Subject: [PATCH] Remove support for IE11 and dead browsers

Handlebars v5 will target modern browsers,
while older browsers will still receive support
via version 4.x.
---
 README.markdown                                 | 13 ++++++-------
 package-lock.json                               | 17 -----------------
 package.json                                    |  8 +++++++-
 spec/.eslintrc                                  | 11 +----------
 .../integration/multi-nodejs-test/.eslintrc.js  |  2 +-
 5 files changed, 15 insertions(+), 36 deletions(-)

diff --git a/README.markdown b/README.markdown
index 80bfdeb54..496846dce 100644
--- a/README.markdown
+++ b/README.markdown
@@ -79,17 +79,16 @@ There are a few Mustache behaviors that Handlebars does not implement.
 Supported Environments
 ----------------------
 
-Handlebars has been designed to work in any ECMAScript 3 environment. This includes
+Handlebars has been designed to work in any ECMAScript 7 (2016) environment. This includes
 
-- Node.js 12+
+- Node.js
 - Chrome
 - Firefox
-- Safari 5+
-- Opera 11+
-- IE 6+
+- Safari
+- Edge
+
+If you need to support older environments, use Handlebars version 4.
 
-Older versions and other runtimes are likely to work but have not been formally
-tested. The compiler requires `JSON.stringify` to be implemented natively or via a polyfill. If using the precompiler this is not necessary.
 
 Performance
 -----------
diff --git a/package-lock.json b/package-lock.json
index fb26ce6e4..34af73fe4 100644
--- a/package-lock.json
+++ b/package-lock.json
@@ -32,7 +32,6 @@
         "eslint": "^6.7.2",
         "eslint-config-prettier": "^6.7.0",
         "eslint-plugin-compat": "^3.13.0",
-        "eslint-plugin-es5": "^1.4.1",
         "fs-extra": "^8.1.0",
         "grunt": "^1.0.4",
         "grunt-babel": "^5.0.0",
@@ -4134,15 +4133,6 @@
       "integrity": "sha512-3wdGidZyq5PB084XLES5TpOSRA3wjXAlIWMhum2kRcv/41Sn2emQ0dycQW4uZXLejwKvg6EsvbdlVL+FYEct7A==",
       "dev": true
     },
-    "node_modules/eslint-plugin-es5": {
-      "version": "1.5.0",
-      "resolved": "https://registry.npmjs.org/eslint-plugin-es5/-/eslint-plugin-es5-1.5.0.tgz",
-      "integrity": "sha512-Qxmfo7v2B7SGAEURJo0dpBweFf+JU15kSyALfiB2rXWcBuJ96r6X9kFHXFnhdopPHCaHjoQs1xQPUJVbGMb1AA==",
-      "dev": true,
-      "peerDependencies": {
-        "eslint": ">= 3.0.0"
-      }
-    },
     "node_modules/eslint-scope": {
       "version": "5.0.0",
       "resolved": "https://registry.npmjs.org/eslint-scope/-/eslint-scope-5.0.0.tgz",
@@ -17935,13 +17925,6 @@
         }
       }
     },
-    "eslint-plugin-es5": {
-      "version": "1.5.0",
-      "resolved": "https://registry.npmjs.org/eslint-plugin-es5/-/eslint-plugin-es5-1.5.0.tgz",
-      "integrity": "sha512-Qxmfo7v2B7SGAEURJo0dpBweFf+JU15kSyALfiB2rXWcBuJ96r6X9kFHXFnhdopPHCaHjoQs1xQPUJVbGMb1AA==",
-      "dev": true,
-      "requires": {}
-    },
     "eslint-scope": {
       "version": "5.0.0",
       "resolved": "https://registry.npmjs.org/eslint-scope/-/eslint-scope-5.0.0.tgz",
diff --git a/package.json b/package.json
index 22373f5a4..2c84473e5 100644
--- a/package.json
+++ b/package.json
@@ -43,7 +43,6 @@
     "eslint": "^6.7.2",
     "eslint-config-prettier": "^6.7.0",
     "eslint-plugin-compat": "^3.13.0",
-    "eslint-plugin-es5": "^1.4.1",
     "fs-extra": "^8.1.0",
     "grunt": "^1.0.4",
     "grunt-babel": "^5.0.0",
@@ -113,6 +112,13 @@
     "types/*.d.ts",
     "runtime.d.ts"
   ],
+  "browserslist": [
+    "last 2 versions",
+    "Firefox ESR",
+    "not dead",
+    "not IE 11",
+    "maintained node versions"
+  ],
   "husky": {
     "hooks": {
       "pre-commit": "lint-staged"
diff --git a/spec/.eslintrc b/spec/.eslintrc
index 076b25a8e..4c7e86028 100644
--- a/spec/.eslintrc
+++ b/spec/.eslintrc
@@ -1,12 +1,5 @@
 {
-  "extends": [
-    "../.eslintrc.js",
-    "plugin:es5/no-es2015",
-    "prettier"
-  ],
-  "plugins": [
-    "es5"
-  ],
+  "extends": ["../.eslintrc.js"],
   "globals": {
     "CompilerContext": true,
     "Handlebars": true,
@@ -16,8 +9,6 @@
     "shouldThrow": true,
     "expectTemplate": true,
     "compileWithPartials": true,
-    "console": true,
-    "require": true,
     "suite": true,
     "equal": true,
     "equals": true,
diff --git a/tests/integration/multi-nodejs-test/.eslintrc.js b/tests/integration/multi-nodejs-test/.eslintrc.js
index fcc705596..2b9bb339c 100644
--- a/tests/integration/multi-nodejs-test/.eslintrc.js
+++ b/tests/integration/multi-nodejs-test/.eslintrc.js
@@ -1,5 +1,5 @@
 module.exports = {
-  extends: ['eslint:recommended', 'plugin:es5/no-es2015', 'prettier'],
+  extends: ['eslint:recommended', 'prettier'],
   globals: {
     self: false
   },
